@@ -21,19 +21,22 @@ import os
 import sys
 sys.path.append('.')
 
+import tiddlyweb.stores.text
 from tiddlyweb.store import NoBagError
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.model.recipe import Recipe
 from tiddlyweb import control
 
-from fixtures import reset_textstore, recipe_list, teststore
+from fixtures import reset_textstore, recipe_list, _teststore
 
 import py.test
 
 def setup_module(module):
     reset_textstore()
-    module.store = teststore()
+    module.store = _teststore()
+    if type(module.store.storage) != tiddlyweb.stores.text.Store:
+        py.test.skip('skipping this test for non-text store')
 
 def test_no_bag_for_tiddler():
     tiddler = Tiddler(title='testnobag')
