@@ -6,6 +6,7 @@ import urllib
 
 from tiddlyweb.serializations import SerializationInterface
 from tiddlyweb.web.util import encode_name
+from tiddlyweb.wikitext import render_wikitext
 
 
 class Serialization(SerializationInterface):
@@ -57,7 +58,8 @@ class Serialization(SerializationInterface):
         server_prefix = self._server_prefix()
         lines = []
         for tiddler in bag.list_tiddlers():
-            base, base_link, wiki_link, title = self._tiddler_list_info(tiddler)
+            base, base_link, wiki_link, title = \
+                    self._tiddler_list_info(tiddler)
             if bag.revbag:
                 line = self._tiddler_revision_info(base, base_link, tiddler)
                 wiki_link += '/%s/revisions' % encode_name(tiddler.title)
@@ -101,12 +103,12 @@ class Serialization(SerializationInterface):
         title = 'Bags in Recipe %s' % recipe.name
         tiddler_link = '%s/tiddlers' % encode_name(recipe.name)
         return """
+<div class="tiddlerslink"><a href="%s">Tiddlers in Recipe</a></div>
 <div id="recipedesc" class="description">%s</div>
 <ul id="recipe" class="listing">
 %s
 </ul>
-<div class="tiddlerslink"><a href="%s">Tiddlers in Recipe</a></div>
-""" % (recipe.desc, output, tiddler_link)
+""" % (tiddler_link, recipe.desc, output)
 
     def bag_as(self, bag):
         """
@@ -126,12 +128,17 @@ class Serialization(SerializationInterface):
         DIV. If wikklytext is available the wikitext
         will be rendered into formatted HTML.
         """
-        try:
-            return self._tiddler_to_wikklyhtml(tiddler)
-        except ImportError:
-            return (self._tiddler_div(tiddler) + '<pre>%s</pre>' %
-                    self._html_encode(tiddler.text) + '</div>')
-
+        if tiddler.recipe:
+            list_link = 'recipes/%s/tiddlers' % encode_name(tiddler.recipe)
+            list_title = 'Tiddlers in Recipe %s' % tiddler.recipe
+        else:
+            list_link = 'bags/%s/tiddlers' % encode_name(tiddler.bag)
+            list_title = 'Tiddlers in Bag %s' % tiddler.bag
+        list_html = ('<div class="tiddlerslink"><a href="%s" ' % list_link +
+                'title="tiddler list">%s</a></div>' % list_title)
+        html = render_wikitext(tiddler, list_link, self.environ)
+        self.environ['tiddlyweb.title'] = tiddler.title
+        return list_html + self._tiddler_div(tiddler) + html + '</div>'
 
     def _server_prefix(self):
         """
@@ -196,7 +203,8 @@ class Serialization(SerializationInterface):
         else:
             base = 'bags'
             base_link = encode_name(tiddler.bag)
-            wiki_link = '%s/bags/%s/tiddlers' % (self._server_prefix(), base_link)
+            wiki_link = '%s/bags/%s/tiddlers' % (self._server_prefix(),
+                    base_link)
             title = 'Tiddlers in Bag %s' % tiddler.bag
         return base, base_link, wiki_link, title
 
@@ -213,31 +221,3 @@ class Serialization(SerializationInterface):
             tiddler.revision,
             tiddler.title,
             tiddler.revision))
-
-    def _tiddler_to_wikklyhtml(self, tiddler):
-        """
-        Render tiddler.text to HTML using wikklytext.
-        """
-        server_prefix = self._server_prefix()
-        if tiddler.recipe:
-            list_link = 'recipes/%s/tiddlers' % encode_name(tiddler.recipe)
-            list_title = 'Tiddlers in Recipe %s' % tiddler.recipe
-        else:
-            list_link = 'bags/%s/tiddlers' % encode_name(tiddler.bag)
-            list_title = 'Tiddlers in Bag %s' % tiddler.bag
-
-        from tiddlyweb.wikklyhtml import wikitext_to_wikklyhtml
-        html = wikitext_to_wikklyhtml('%s/' % server_prefix,
-                list_link, tiddler.text)
-        # Have to be very careful in the following about UTF-8 handling
-        # because wikklytext wants to encode its output.
-        self.environ['tiddlyweb.title'] = tiddler.title
-        return """
-<div class="tiddlerslink"><a href="%s" title="tiddler list">%s</a></div>
-%s
-%s
-</div>
-""" % ('%s/%s' % (server_prefix, list_link),
-        list_title.encode('utf-8'),
-        self._tiddler_div(tiddler).encode('utf-8'),
-        html)
